===============
About PyScanFCS
===============
When a membrane is scanned perpendicularly to its surface, the fluorescence
signal originating from the membrane itself must be separated from the signal
of the surrounding medium for an FCS analysis. PyScanFCS interactively extracts
the fluctuating fluorescence signal from such measurements and applies a
multiple-tau algorithm. The obtained correlation curves can be evaluated using
PyCorrFit.

Supported operating systems
---------------------------
- Windows 7 and higher
- Linux (Debian-based)
- Any other operating system with a Python 3.6 installation (via pip)

Supported filetypes
-------------------
- Correlator.com Flex correlator (~.dat - photon stream data)

How to cite
-----------
Müller, P., Schwille, P., and Weidemann, T.
Fluorescence Spectroscopy and Microscopy, chapter: *Scanning Fluorescence
Correlation Spectroscopy (SFCS) with a Scan Path Perpendicular to the Membrane
Plane*. Methods in Molecular Biology, Humana Press, Springer, New York. 2014,
635-651. doi:`10.1007/978-1-62703-649-8_29 <http://dx.doi.org/10.1007/978-1-62703-649-8_29>`_ - 
`download author’s manuscript <https://github.com/FCS-analysis/PyScanFCS/wiki/Mueller,Weidemann_PerpLSFCS_FlSpecMicr_AuthorsManuscript_2015-01.pdf>`_.